---
gitea: none
include_toc: true
---
# dictionaries/rougail/01-base.yml

```yaml
---
version: '1.1'
leader:
  redefine: true
  hidden: true
```
# dictionaries/rougail/00-base.yml

```yaml
---
version: '1.1'
leader:  # a leadership
  type: leadership
  leader:
    description: a leader
    multi: true
    mandatory: false
  follower:
    description: a follower
    mandatory: false
```
